@@ -56,7 +56,7 @@ from msilib._msi import (
     UuidCreate,
 )
 
-__version__ = "0.4.0"
+__version__ = "0.4.2"
 
 __all__ = [
     "CAB",
@@ -135,6 +135,9 @@ __all__ = [
 AMD64 = platform.machine() in ("x64", "x86_64", "AMD64")
 ARM64 = platform.machine() in ("aarch64", "arm64", "ARM64")
 
+# Keep msilib.Win64 around to preserve backwards compatibility.
+Win64 = AMD64
+
 # Partially taken from Wine
 datasizemask = 0x00FF
 type_valid = 0x0100
@@ -292,10 +295,15 @@ def init_database(
     else:
         si.SetProperty(PID_TEMPLATE, "Intel;1033")
     si.SetProperty(PID_REVNUMBER, gen_uuid())
-    si.SetProperty(
-        PID_WORDCOUNT, 2
-    )  # long file names, compressed, original media
-    si.SetProperty(PID_PAGECOUNT, 200)
+    # https://learn.microsoft.com/en-us/windows/win32/msi/word-count-summary
+    # 2 = long file names, compressed, original media
+    si.SetProperty(PID_WORDCOUNT, 2)
+    # https://learn.microsoft.com/en-us/windows/win32/msi/page-count-summary
+    # https://learn.microsoft.com/en-us/windows/win32/msi/using-64-bit-windows-installer-packages
+    if ARM64:
+        si.SetProperty(PID_PAGECOUNT, 500)  # minimum of Windows Installer 5.0
+    else:
+        si.SetProperty(PID_PAGECOUNT, 200)  # minimum of Windows Installer 2.0
     si.SetProperty(PID_APPNAME, "Python MSI Library")
     # XXX more properties
     si.Persist()
@@ -433,7 +441,7 @@ class Directory:
         if component is None:
             component = self.logical
         self.component = component
-        # https://learn.microsoft.com/pt-br/windows/win32/msi/component-table
+        # https://learn.microsoft.com/en-us/windows/win32/msi/component-table
         if AMD64 or ARM64:
             flags |= 256  # msidbComponentAttributes64bit
         if keyfile:
